<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 <xsl:output method="text"
	    encoding="ISO-8859-1"/>
<xsl:template match="package" mode="classpath">lib/<xsl:value-of select="@name"/>.jar$(PATH_SEPARATOR)</xsl:template>		
<xsl:template match="package" mode="lib">lib/<xsl:value-of select="@name"/>.jar </xsl:template>		

<xsl:template match="package" mode="rule">
$(JARPATH)/<xsl:value-of select="@name"/>.<xsl:value-of select="@version"/>.jar:
	wget $(HTTPJARS)/<xsl:value-of select="@name"/>.<xsl:value-of select="@version"/>.jar -O $@

lib/<xsl:value-of select="@name"/>.jar: $(JARPATH)/<xsl:value-of select="@name"/>.<xsl:value-of select="@version"/>.jar .init.dirs
	$(LN) $&lt; $@

</xsl:template>


<xsl:template match="/">
CYGWIN=$(shell test -x /usr/bin/cygpath &amp;&amp; echo true || echo false)
ifeq ($(CYGWIN),true)
	PATH_SEPARATOR=;
	LN=cp
else
	PATH_SEPARATOR=:
	LN=ln -sf
endif	

MODE=Debug
FORCECONFIG=$(shell build/jco.sh $(MODE) $(DEFINES))
	
HASJARPATH=$(shell test -d "$(JARPATH)" &amp;&amp; echo true ||echo false)
ifeq ($(HASJARPATH),false)
	JARPATH=$(shell cd ../jars ; pwd)
endif

HTTPJARS=http://www.eduvax.net/jdev/jars

PACKAGE=<xsl:value-of select="/package/@name"/>
VERSION=$(shell cat .egpi-brspec)
REVISION=$(shell svnversion | sed 's/:/./')
MAINCLASS=<xsl:value-of select="/package/@main"/>
SHORTNAME=$(patsubst net.eduvax.%,%,$(PACKAGE))
<xsl:choose>
	<xsl:when test="count(/package/@license)=0">
LICENSE=lgpl-2.0
LICENSEFILE=build/lgpl-2.0.txt
	</xsl:when>
	<xsl:otherwise>	
LICENSE=<xsl:value-of select="/package/@license"/>
LICENSEFILE=build/<xsl:value-of select="/package/@license"/>.txt
	</xsl:otherwise>
</xsl:choose>	

lib/%.jar: $(JARPATH)/%.jar
	$(LN) $&lt; $@

$(JARPATH)/%.jar:	
	wget $(patsubst $(JARPATH)/%.jar,$(HTTPJARS)/%.jar,$@) -O $@
	
all: bin/$(PACKAGE).jar
	make all.local

all.local::


JAR=jar
JAVA=java
ifeq ($(MODE),Release)
	JAVAC=javac -g:none
else
	JAVAC=javac -g
endif
JAVADOC=javadoc -private
DEBUG=-O
CLASSP=<xsl:apply-templates select="/package/require/package" mode="classpath"/>src/res
RUNCP=<xsl:apply-templates select="/package/require/package" mode="classpath"/>bin/$(PACKAGE).jar
<xsl:choose>
<xsl:when test="concat('plop',/package/@license)='plop'">
LICENSE=lgpl-2.0
</xsl:when>
<xsl:otherwise>
LICENSE=<xsl:value-of select="/package/@license"/>
</xsl:otherwise>
</xsl:choose>
LICENSEFILE=build/$(LICENSE).txt
ifeq ($(JARPATH),lib)
DISTLIB=
LIBS=
else
DISTLIB=$(LIBS) lib/junit.jar lib/net.eduvax.test.jar
LIBS=<xsl:apply-templates select="/package/require/package" mode="lib"/>
endif
JFLAGS=-classpath "${CLASSP}" -d bin -sourcepath "src$(PATH_SEPARATOR)obj" $(DEBUG)
CLASSFILES=$(patsubst src/%.java,bin/%.class,$(shell find src -name '*.java' | grep -v "^src/test/"))
TESTCLASSP=lib/junit.jar$(PATH_SEPARATOR)lib/net.eduvax.test.jar$(PATH_SEPARATOR)tbin
TESTCLASSFILES=$(patsubst src/test/%.java,tbin/test/%.class,$(shell find src/test -name 'Test*.java'))
TESTSUITE=$(patsubst tbin/test/%.class,test.%,$(TESTCLASSFILES))
RESFILES=$(patsubst src/%,bin/%,$(shell find src -name '*.html' -o -name '*.png' -o -name '*.properties' | grep -v "^src/test/"))

HASLOCAL=$(shell test -f src/Makefile &amp;&amp; echo true || echo false)
ifeq ($(HASLOCAL),true)
include src/Makefile
endif

setup: $(LIBS) .project .classpath 

header:
	build/addHeader.sh $(LICENSE)

config:	
	build/jco.sh $(MODE) $(DEFINES)

bin/%.class: src/%.java .init.dirs $(LIBS) $(FORCECONFIG)
	${JAVAC} ${JFLAGS} $&lt; 

bin/%.html: src/%.html	
	cp $&lt; $@

bin/%.png: src/%.png	
	cp $&lt; $@

bin/%.properties: src/%.properties	
	cp $&lt; $@

tbin/test/%.class: src/test/%.java .init.dirs bin/$(PACKAGE).jar $(LIBS) lib/junit.jar lib/net.eduvax.test.jar
	${JAVAC} -classpath "${TESTCLASSP}" -d tbin -sourcepath src $(DEBUG) $&lt;

%: tbin/test/%.class
	$(JAVA) -cp "$(TESTCLASSP)" net.eduvax.test.TestRunner test.$@
	
<xsl:apply-templates select="/package/require/package" mode="rule"/>

Makefile: build/jmakefile.xsl src/package.xml build/setup.sh
	xsltproc build/jmakefile.xsl src/package.xml &gt; Makefile 

.classpath: build/classpath.xsl src/package.xml build/setup.sh
	xsltproc build/classpath.xsl src/package.xml &gt; .classpath 

.project: build/project.xsl src/package.xml build/setup.sh
	xsltproc --param version `cat .egpi-brspec | sed 's/\.[0-9]*$$//g'` build/project.xsl src/package.xml &gt; .project
	
.init.dirs: Makefile
	mkdir -p bin dist lib tbin obj doc ; \
	date > .init.dirs ; \
	make .init.dirs.local 
	
.init.dirs.local::

clean: dist.clean
	rm -rf tbin bin obj *.jar .init.dirs $(PACKAGE)*.tar.gz doc/* ; \
	make clean.local

clean.local::	

clean.doc:
	rm -rf doc ; \
	make clean.doc.local

clean.doc.local::	

clean.all: clean clean.doc clean.dist

bin/$(PACKAGE).jar: $(CLASSFILES) $(RESFILES)
	cd bin &amp;&amp; \
	rm -rf $(PACKAGE).jar ; \
	echo "Main-Class: "$(MAINCLASS) > ../Manifest ; \
	echo "Class-Path: "$(patsubst lib/%.jar,../lib/%.jar,$(LIBS))" ../res" >> ../Manifest ; \
	echo "Implementation-Version: "$(VERSION)-$(REVISION) >> ../Manifest ; \
	echo "Implementation-Vendor: Sebastien Devaux" >> ../Manifest ; \
	echo "Implementation-Vendor-Id: eduvax.net" >> ../Manifest ; \
	echo "Implementation-URL: "http://www.eduvax.net/jdev/$(PACKAGE) >> ../Manifest ; \
	echo "Implementation-Licence: "$(LICENSE) >> ../Manifest ; \
	echo "Build-Date: "`date` >> ../Manifest ; \
	echo "Build-Host: "`hostname` >> ../Manifest ; \
	echo "Build-Option: "$(MODE) $(DEFINES) >> ../Manifest ; \
	rm -rf jc ; \
	$(JAR) cvf $(PACKAGE).jar * &amp;&amp; \
	jar uvmf ../Manifest $(PACKAGE).jar ; \
	cd .. ; \
	rm Manifest

install: bin/$(PACKAGE).jar
	mkdir -p ${JARPATH} ; \
	cp bin/$(PACKAGE).jar ${JARPATH}/$(PACKAGE).$(VERSION)-$(REVISION).jar ; \
	make install.local
	
install.local::

run: bin/$(PACKAGE).jar
	$(JAVA) -jar bin/$(PACKAGE).jar $(RUNARGS) ; \
	make run.local

run.local::	

doc: .init.dirs
	$(JAVADOC) -d doc/api -classpath "$(CLASSP)" -sourcepath src -subpackages $(PACKAGE) ; \
	make doc.local

doc.local::	
	
test: $(TESTCLASSFILES)
	$(JAVA) -cp "$(TESTCLASSP)" net.eduvax.test.TestRunner $(TESTSUITE) ; \
	make test.local
	
test.local::

dist/$(PACKAGE)-src.$(VERSION)-$(REVISION).tar.gz: Makefile $(DISTLIB)
	mkdir -p $(PACKAGE)-src.$(VERSION)-$(REVISION) ; \
	cp $(LICENSEFILE) $(PACKAGE)-src.$(VERSION)-$(REVISION)/COPYING ; \
	ln -s ../src $(PACKAGE)-src.$(VERSION)-$(REVISION)/src ; \
	ln -s ../lib $(PACKAGE)-src.$(VERSION)-$(REVISION)/lib ; \
	ln -s ../Makefile $(PACKAGE)-src.$(VERSION)-$(REVISION)/Makefile ; \
	ln -s ../build $(PACKAGE)-src.$(VERSION)-$(REVISION)/build ; \
	ln -s ../.egpi-brspec $(PACKAGE)-src.$(VERSION)-$(REVISION)/.egpi-brspec ; \
	tar cvzhf dist/$(PACKAGE)-src.$(VERSION)-$(REVISION).tar.gz \
		--exclude .svn --exclude CVS $(PACKAGE)-src.$(VERSION)-$(REVISION) ; \
	rm -rf $(PACKAGE)-src.$(VERSION)-$(REVISION)	

dist.src: dist/$(PACKAGE)-src.$(VERSION)-$(REVISION).tar.gz		
	make dist.local

clean.dist:
	rm -rf $(PACKAGE)*.tar.gz

dist.local::

dist.bin: bin/$(PACKAGE).jar
	mkdir $(PACKAGE).$(VERSION)-$(REVISION) $(PACKAGE).$(VERSION)-$(REVISION)/bin $(PACKAGE).$(VERSION)-$(REVISION)/lib ; \
	cp bin/$(PACKAGE).jar $(PACKAGE).$(VERSION)-$(REVISION)/bin ; \
	cp $(LIBS) $(PACKAGE).$(VERSION)-$(REVISION)/lib ; \
	echo "#!/bin/sh" > $(PACKAGE).$(VERSION)-$(REVISION)/bin/$(SHORTNAME).sh ; \
	echo 'exec java -jar `dirname $$0`/'"$(PACKAGE).jar"' "$$@"' >> $(PACKAGE).$(VERSION)-$(REVISION)/bin/$(SHORTNAME).sh ; \
	chmod a+x $(PACKAGE).$(VERSION)-$(REVISION)/bin/$(SHORTNAME).sh ; \
	echo "java -jar $(PACKAGE).jar" > $(PACKAGE).$(VERSION)-$(REVISION)/bin/$(SHORTNAME).bat ; \
	cp -r src/res $(PACKAGE).$(VERSION)-$(REVISION)/res ; \
	find $(PACKAGE).$(VERSION)-$(REVISION)/res -name ".svn" | xargs rm -rf ; \
	cp $(LICENSEFILE) $(PACKAGE).$(VERSION)-$(REVISION)/COPYING ; \<xsl:choose>
		<xsl:when test="count(/package/izpack)=1">
	sed s/__VERSION__/$(VERSION)-$(REVISION)/ src/<xsl:value-of select="/package/izpack/@file"/> > izpack.xml ; \
	izpack izpack.xml -o $(PACKAGE).$(VERSION)-$(REVISION).jar -b $(PACKAGE).$(VERSION)-$(REVISION) ; \
	rm izpack.xml ; \</xsl:when>
		<xsl:otherwise>
	tar cvzf dist/$(PACKAGE).$(VERSION)-$(REVISION).tar.gz $(PACKAGE).$(VERSION)-$(REVISION) ; \</xsl:otherwise>
	</xsl:choose>
	rm -rf $(PACKAGE).$(VERSION)-$(REVISION) ; \
	make dist.bin.local

dist.eclipse: bin/$(PACKAGE).jar
	cd src ; $(JAR) cvf ../src.zip `find . -type f | fgrep -v .svn`  ; cd .. ; \
	cp $(LICENSEFILE) COPYING ; \
	cp bin/$(PACKAGE).jar dist/$(PACKAGE).$(VERSION).jar
	$(JAR) uvf dist/$(PACKAGE).$(VERSION).jar src.zip COPYING ; \
	rm COPYING src.zip

dist.clean:
	rm -rf dist/$(PACKAGE).$(VERSION).jar dist/$(PACKAGE).$(VERSION)-$(REVISION).tar.gz dist/$(PACKAGE)-src.$(VERSION)-$(REVISION).tar.gz

dist.bin.local::	

dist.all: dist.src dist.bin dist.eclipse

check.dist: dist.src
	tar -xvzf dist/$(PACKAGE)-src.$(VERSION).tar.gz ; \
	cd $(PACKAGE)-src.$(VERSION)-$(REVISION) ; \
	make JARPATH=lib test ; \
	make check.dist.local ; \
	cd .. ; \
	rm -rf $(PACKAGE)-src.$(VERSION)-$(REVISION)

check.dist.local::	
	
</xsl:template>	
</xsl:stylesheet>
